@@ -27,6 +27,7 @@
 #include "controladaptor.h"
 #include "dbusconnectionpool.h"
 #include "itemfetchjob.h"
+#include "kdepimlibs-version.h"
 #include "monitor_p.h"
 #include "servermanager_p.h"
 #include "session.h"
@@ -514,12 +515,12 @@ QString AgentBase::parseArguments( int argc, char **argv )
     kDebug() << "Identifier argument missing";
     exit( 1 );
   }
- 
+
   const QFileInfo fi( QString::fromLocal8Bit( argv[0] ) );
   // strip off full path and possible .exe suffix
   const QByteArray catalog = fi.baseName().toLatin1();
 
-  KCmdLineArgs::init( argc, argv, identifier.toLatin1(), catalog, ki18n( "Akonadi Agent" ), "0.1",
+  KCmdLineArgs::init( argc, argv, identifier.toLatin1(), catalog, ki18n( "Akonadi Agent" ), KDEPIMLIBS_VERSION,
                       ki18n( "Akonadi Agent" ) );
 
   KCmdLineOptions options;
