@@ -31,6 +31,7 @@
 
 #include <KDE/KIcon>
 #include <KDE/KLocale>
+#include <KDE/KMessageBox>
 #include <KDE/KUrl>
 
 #include <akonadi/attributefactory.h>
@@ -47,9 +48,6 @@
 #include "kdebug.h"
 #include "pastehelper_p.h"
 
-// TODO:
-// * Implement ordering support.
-
 Q_DECLARE_METATYPE( QSet<QByteArray> )
 
 using namespace Akonadi;
@@ -79,6 +77,7 @@ EntityTreeModel::~EntityTreeModel()
 
   foreach ( const QList<Node*> &list, d->m_childEntities )
     qDeleteAll( list );
+  d->m_rootNode = 0;
 
   delete d_ptr;
 }
@@ -140,7 +139,7 @@ QVariant EntityTreeModel::entityData( const Item &item, int column, int role ) c
         } else {
           if (!item.remoteId().isEmpty())
             return item.remoteId();
-          return QLatin1String("<") + QString::number( item.id() ) + QLatin1String(">");
+          return QString(QLatin1String("<") + QString::number( item.id() ) + QLatin1String(">"));
         }
         break;
       case Qt::DecorationRole:
@@ -182,7 +181,7 @@ QVariant EntityTreeModel::entityData( const Collection &collection, int column,
         }
         if ( !collection.name().isEmpty() )
           return collection.name();
-        return QString::fromLatin1( "Loading ..." );
+        return i18n( "Loading..." );
       }
       break;
     case Qt::DecorationRole:
@@ -220,7 +219,7 @@ QVariant EntityTreeModel::data( const QModelIndex & index, int role ) const
 
   const Node *node = reinterpret_cast<Node *>( index.internalPointer() );
 
-  if ( ParentCollectionRole == role ) {
+  if ( ParentCollectionRole == role && d->m_collectionFetchStrategy != FetchNoCollections ) {
     const Collection parentCollection = d->m_collections.value( node->parent );
     Q_ASSERT( parentCollection.isValid() );
 
@@ -290,6 +289,8 @@ QVariant EntityTreeModel::data( const QModelIndex & index, int role ) const
       return QVariant();
 
     switch ( role ) {
+      case ParentCollectionRole:
+        return QVariant::fromValue( item.parentCollection() );
       case MimeTypeRole:
         return item.mimeType();
         break;
@@ -385,12 +386,9 @@ Qt::ItemFlags EntityTreeModel::flags( const QModelIndex & index ) const
     // Rights come from the parent collection.
 
     Collection parentCollection;
-    if ( !index.parent().isValid() )
-    {
+    if ( !index.parent().isValid() ) {
       parentCollection = d->m_rootCollection;
-    }
-    else
-    {
+    } else {
       const Node *parentNode = reinterpret_cast<Node *>( index.parent().internalPointer() );
 
       parentCollection = d->m_collections.value( parentNode->id );
@@ -494,6 +492,17 @@ bool EntityTreeModel::dropMimeData( const QMimeData * data, Qt::DropAction actio
             kDebug() << "unwanted collection" << mimeChecker.wantedMimeTypes() << collection.contentMimeTypes();
             return false;
           }
+
+          if ( url.hasQueryItem( QLatin1String( "name" ) ) ) {
+            const QString collectionName = url.queryItemValue( QLatin1String( "name" ) );
+            const QStringList collectionNames = d->childCollectionNames( destCollection );
+
+            if ( collectionNames.contains( collectionName ) ) {
+              KMessageBox::error( 0, i18n( "The target collection '%1' contains already\na collection with name '%2'.",
+                                           destCollection.name(), collection.name() ) );
+              return false;
+            }
+          }
         } else {
           const Item item = d->m_items.value( Item::fromUrl( url ).id() );
           if ( item.isValid() ) {
@@ -570,7 +579,7 @@ QModelIndex EntityTreeModel::parent( const QModelIndex & index ) const
   if ( !index.isValid() )
     return QModelIndex();
 
-  if ( d->m_collectionFetchStrategy == InvisibleCollectionFetch )
+  if ( d->m_collectionFetchStrategy == InvisibleCollectionFetch || d->m_collectionFetchStrategy == FetchNoCollections )
     return QModelIndex();
 
   const Node *node = reinterpret_cast<Node*>( index.internalPointer() );
@@ -590,6 +599,7 @@ QModelIndex EntityTreeModel::parent( const QModelIndex & index ) const
       return createIndex( 0, 0, reinterpret_cast<void *>( d->m_rootNode ) );
   }
 
+  Q_ASSERT( collection.parentCollection().isValid() );
   const int row = d->indexOf<Node::Collection>( d->m_childEntities.value( collection.parentCollection().id() ), collection.id() );
 
   Q_ASSERT( row >= 0 );
@@ -602,38 +612,33 @@ int EntityTreeModel::rowCount( const QModelIndex & parent ) const
 {
   Q_D( const EntityTreeModel );
 
-  if ( d->m_collectionFetchStrategy == InvisibleCollectionFetch )
-  {
+  if ( d->m_collectionFetchStrategy == InvisibleCollectionFetch || d->m_collectionFetchStrategy == FetchNoCollections ) {
     if ( parent.isValid() )
       return 0;
     else
       return d->m_items.size();
   }
 
-  const Node *node = reinterpret_cast<Node*>( parent.internalPointer() );
-
-  qint64 id;
   if ( !parent.isValid() ) {
     // If we're showing the root collection then it will be the only child of the root.
     if ( d->m_showRootCollection )
       return d->m_childEntities.value( -1 ).size();
-
-    id = d->m_rootCollection.id();
-  } else {
-
-    if ( !node )
-      return 0;
-
-    if ( Node::Item == node->type )
-      return 0;
-
-    id = node->id;
+    return d->m_childEntities.value( d->m_rootCollection.id() ).size();
   }
 
-  if ( parent.column() <= 0 )
-    return d->m_childEntities.value( id ).size();
+  if ( parent.column() != 0 )
+    return 0;
 
-  return 0;
+  const Node *node = reinterpret_cast<Node*>( parent.internalPointer() );
+
+  if ( !node )
+    return 0;
+
+  if ( Node::Item == node->type )
+    return 0;
+
+  Q_ASSERT( parent.isValid() );
+  return d->m_childEntities.value( node->id ).size();
 }
 
 int EntityTreeModel::entityColumnCount( HeaderGroup headerGroup ) const
@@ -650,8 +655,7 @@ QVariant EntityTreeModel::entityHeaderData( int section, Qt::Orientation orienta
   // Not needed in this model.
   Q_UNUSED( headerGroup );
 
-  if ( section == 0 && orientation == Qt::Horizontal && role == Qt::DisplayRole )
-  {
+  if ( section == 0 && orientation == Qt::Horizontal && role == Qt::DisplayRole ) {
     if ( d->m_rootCollection == Collection::root() )
       return i18nc( "@title:column Name of a thing", "Name" );
     return d->m_rootCollection.name();
@@ -684,7 +688,7 @@ QMimeData *EntityTreeModel::mimeData( const QModelIndexList &indexes ) const
     const Node *node = reinterpret_cast<Node*>( index.internalPointer() );
 
     if ( Node::Collection == node->type )
-      urls << d->m_collections.value( node->id ).url();
+      urls << d->m_collections.value( node->id ).url( Collection::UrlWithName );
     else if ( Node::Item == node->type )
       urls << d->m_items.value( node->id ).url( Item::UrlWithMimeType );
     else // if that happens something went horrible wrong
@@ -838,7 +842,7 @@ bool EntityTreeModel::hasChildren( const QModelIndex &parent ) const
 {
   Q_D( const EntityTreeModel );
 
-  if ( d->m_collectionFetchStrategy == InvisibleCollectionFetch )
+  if ( d->m_collectionFetchStrategy == InvisibleCollectionFetch || d->m_collectionFetchStrategy == FetchNoCollections )
     return parent.isValid() ? false : !d->m_items.isEmpty();
 
   // TODO: Empty collections right now will return true and get a little + to expand.
@@ -1047,7 +1051,6 @@ void EntityTreeModel::setCollectionFetchStrategy( CollectionFetchStrategy strate
   d->beginResetModel();
   d->m_collectionFetchStrategy = strategy;
 
-
   if ( strategy == FetchNoCollections || strategy == InvisibleCollectionFetch ) {
     disconnect( d->m_monitor, SIGNAL( collectionChanged( const Akonadi::Collection& ) ),
             this, SLOT( monitoredCollectionChanged( const Akonadi::Collection& ) ) );
