@@ -36,6 +36,7 @@ namespace Akonadi
 {
 class ItemFetchJob;
 class ChangeRecorder;
+class AgentInstance;
 }
 
 struct Node
@@ -63,7 +64,7 @@ public:
 
   EntityTreeModelPrivate( EntityTreeModel *parent );
   ~EntityTreeModelPrivate();
-  EntityTreeModel *q_ptr;
+  EntityTreeModel * const q_ptr;
 
   enum RetrieveDepth {
     Base,
@@ -83,7 +84,9 @@ public:
   void collectionsFetched( const Akonadi::Collection::List& );
   void firstCollectionsFetched( const Akonadi::Collection::List& );
   void collectionListFetched( const Akonadi::Collection::List& );
-  void itemsFetched( const Akonadi::Item::List& );
+  void itemsFetched( KJob* );
+  void itemsFetched( const Akonadi::Item::List &items );
+  void itemsFetched( const Collection::Id collectionId, const Akonadi::Item::List &items );
 
   void monitoredCollectionAdded( const Akonadi::Collection&, const Akonadi::Collection& );
   void monitoredCollectionRemoved( const Akonadi::Collection& );
@@ -104,13 +107,20 @@ public:
 
   void monitoredMimeTypeChanged( const QString &mimeType, bool monitored );
   void monitoredCollectionsChanged( const Akonadi::Collection &collection, bool monitored );
+  void monitoredItemsChanged( const Akonadi::Item &item, bool monitored );
   void monitoredResourcesChanged( const QByteArray &resource, bool monitored );
 
   Collection::List getParentCollections( const Item &item ) const;
-  Collection getParentCollection( const Collection &collection ) const;
-  Entity::Id childAt( Collection::Id, int position, bool *ok ) const;
-  Item getItem( Item::Id id ) const;
   void removeChildEntities( Collection::Id collectionId );
+
+  /**
+   * Returns the list of names of the child collections of @p collection.
+   */
+  QStringList childCollectionNames( const Collection &collection ) const;
+
+  /**
+   * Fetch parent collections and insert this @p collection and its parents into the node tree
+   */
   void retrieveAncestors( const Akonadi::Collection& collection );
   void ancestorsFetched( const Akonadi::Collection::List& collectionList );
   void insertCollection( const Akonadi::Collection &collection, const Akonadi::Collection& parent );
@@ -118,6 +128,10 @@ public:
 
   void beginResetModel();
   void endResetModel();
+  /**
+   * Start function for filling the Model, finds and fetches the root of the node tree
+   * Next relevant function for filling the model is startFirstListJob()
+   */
   void fillModel();
 
   ItemFetchJob* getItemFetchJob( const Collection &parent, const ItemFetchScope &scope ) const;
@@ -125,6 +139,7 @@ public:
   void runItemFetchJob( ItemFetchJob* itemFetchJob, const Collection &parent ) const;
   void changeFetchState( const Collection &parent );
   void agentInstanceAdvancedStatusChanged( const QString&, const QVariantMap& );
+  void agentInstanceRemoved( const Akonadi::AgentInstance &instace );
 
   QHash<Collection::Id, Collection> m_collections;
   QHash<Entity::Id, Item> m_items;
@@ -148,12 +163,23 @@ public:
   bool m_showRootCollection;
   QHash<Collection::Id, uint> m_collectionSyncProgress;
 
-  void rootCollectionFetched( const Collection::List &list );
+  /**
+   * Called after the root collection was fetched by fillModel
+   *
+   * Initiates further fetching of collections depending on the monitored collections
+   * (in the monitor) and the m_collectionFetchStrategy.
+   *
+   * Further collections are either fetched directly with fetchCollections and
+   * fetchItems or, in case that collections or resources are monitored explicitly
+   * via fetchTopLevelCollections
+   */
   void startFirstListJob();
 
   void serverStarted();
 
+  void monitoredItemsRetrieved( KJob* job );
   void firstFetchJobDone( KJob *job );
+  void rootFetchJobDone( KJob *job );
   void fetchJobDone( KJob *job );
   void updateJobDone( KJob *job );
   void pasteJobDone( KJob *job );
@@ -194,7 +220,10 @@ public:
   /**
     @returns True if @p entity or one of its descemdants is hidden.
   */
-  bool isHidden( const Entity &entity ) const;
+  bool isHidden( const Entity &entity, Node::Type type ) const;
+
+  template<typename T>
+  bool isHidden( const T &entity ) const;
 
   bool m_showSystemEntities;
 
