@@ -42,19 +42,39 @@ namespace Akonadi {
 
 class Monitor;
 
+/**
+ * This class exists so that we can create a fake notification source in
+ * unit tests.
+ */
+class AKONADI_TESTS_EXPORT MonitorDependeciesFactory
+{
+public:
+  virtual ~MonitorDependeciesFactory() {}
+  virtual QObject* createNotificationSource(QObject *parent);
+
+  virtual Akonadi::CollectionCache* createCollectionCache(int maxCapacity, Session *session);
+  virtual Akonadi::ItemCache* createItemCache(int maxCapacity, Session *session);
+};
+
+
 /**
  * @internal
  */
 class AKONADI_TESTS_EXPORT MonitorPrivate
 {
   public:
-    MonitorPrivate( Monitor *parent );
-    virtual ~MonitorPrivate() {}
+    MonitorPrivate( MonitorDependeciesFactory *dependenciesFactory_, Monitor *parent );
+    virtual ~MonitorPrivate() {
+      delete dependenciesFactory;
+      delete collectionCache;
+      delete itemCache;
+    }
     void init();
 
     Monitor *q_ptr;
     Q_DECLARE_PUBLIC( Monitor )
-    org::freedesktop::Akonadi::NotificationSource *notificationSource;
+    MonitorDependeciesFactory *dependenciesFactory;
+    QObject* notificationSource;
     Collection::List collections;
     QSet<QByteArray> resources;
     QSet<Item::Id> items;
@@ -64,8 +84,8 @@ class AKONADI_TESTS_EXPORT MonitorPrivate
     ItemFetchScope mItemFetchScope;
     CollectionFetchScope mCollectionFetchScope;
     Session *session;
-    CollectionCache collectionCache;
-    ItemCache itemCache;
+    CollectionCache *collectionCache;
+    ItemCache *itemCache;
     QQueue<NotificationMessage> pendingNotifications;
     QQueue<NotificationMessage> pipeline;
     bool fetchCollection;
@@ -75,6 +95,7 @@ class AKONADI_TESTS_EXPORT MonitorPrivate
     virtual bool connectToNotificationManager();
     bool acceptNotification( const NotificationMessage &msg );
     void dispatchNotifications();
+    void flushPipeline();
 
     // Called when the monitored item/collection changes, checks if the queued messages
     // are still accepted, if not they are removed
@@ -102,7 +123,10 @@ class AKONADI_TESTS_EXPORT MonitorPrivate
     void slotStatisticsChangedFinished( KJob* );
     void slotFlushRecentlyChangedCollections();
 
-    void appendAndCompress( const NotificationMessage &msg  );
+    /**
+      Returns whether a message was appended to @p notificationQueue
+    */
+    bool translateAndCompress( QQueue<NotificationMessage> &notificationQueue, const NotificationMessage &msg  );
 
     virtual void slotNotify( const NotificationMessage::List &msgs );
 
@@ -186,6 +210,8 @@ class AKONADI_TESTS_EXPORT MonitorPrivate
 
     bool isCollectionMonitored( Collection::Id collection ) const
     {
+      if (collection < 0)
+        return false;
       if ( collections.contains( Collection( collection ) ) )
         return true;
       if ( collections.contains( Collection::root() ) )
@@ -212,10 +238,9 @@ class AKONADI_TESTS_EXPORT MonitorPrivate
 
     bool isMoveDestinationResourceMonitored( const NotificationMessage &msg )
     {
-      if ( msg.operation() != NotificationMessage::Move || msg.itemParts().isEmpty() )
+      if ( msg.operation() != NotificationMessage::Move )
         return false;
-      const QByteArray res = *(msg.itemParts().begin());
-      return resources.contains( res );
+      return resources.contains( msg.destinationResource() );
     }
 
     void fetchStatistics( Collection::Id colId )
