@@ -3,7 +3,7 @@
 
   Copyright (c) 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
   Copyright (c) 2006-2007 Christian Weilbach <christian_weilbach@web.de>
-  Copyright (c) 2007-2008 Mike Arthur <mike@mikearthur.co.uk>
+  Copyright (c) 2007-2008 Mike McQuaid <mike@mikemcquaid.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -40,20 +40,20 @@ using namespace KBlog;
 Blogger1::Blogger1( const KUrl &server, QObject *parent )
   : Blog( server, *new Blogger1Private, parent )
 {
-  kDebug() << "Blogger1()";
+  kDebug();
   setUrl( server );
 }
 
 Blogger1::Blogger1( const KUrl &server, Blogger1Private &dd, QObject *parent )
   : Blog( server, dd, parent )
 {
-  kDebug() << "Blogger1()";
+  kDebug();
   setUrl( server );
 }
 
 Blogger1::~Blogger1()
 {
-  kDebug() << "~Blogger1()";
+  kDebug();
 }
 
 QString Blogger1::interfaceName() const
@@ -190,12 +190,13 @@ void Blogger1::removePost( KBlog::BlogPost *post )
 Blogger1Private::Blogger1Private() :
 mXmlRpcClient(0)
 {
+  kDebug();
   mCallCounter = 1;
 }
 
 Blogger1Private::~Blogger1Private()
 {
-  kDebug() << "~Blogger1Private()";
+  kDebug();
   delete mXmlRpcClient;
 }
 
@@ -233,7 +234,7 @@ void Blogger1Private::slotFetchUserInfo( const QList<QVariant> &result, const QV
   Q_Q( Blogger1 );
   Q_UNUSED( id );
 
-  kDebug() << "Blog::slotFetchUserInfo";
+  kDebug();
   kDebug() << "TOP:" << result[0].typeName();
   QMap<QString,QString> userInfo;
   if ( result[0].type() != QVariant::Map ) {
@@ -260,7 +261,7 @@ void Blogger1Private::slotListBlogs( const QList<QVariant> &result, const QVaria
   Q_Q( Blogger1 );
   Q_UNUSED( id );
 
-  kDebug() << "Blog::slotListBlogs";
+  kDebug();
   kDebug() << "TOP:" << result[0].typeName();
   QList<QMap<QString,QString> > blogsList;
   if ( result[0].type() != QVariant::List ) {
@@ -279,9 +280,11 @@ void Blogger1Private::slotListBlogs( const QList<QVariant> &result, const QVaria
     const QMap<QString, QVariant> postInfo = ( *it ).toMap();
     QMap<QString,QString> blogInfo;
     blogInfo[ "id" ] = postInfo["blogid"].toString();
-    blogInfo[ "name" ] = postInfo["blogName"].toString();
+    blogInfo[ "url" ] = postInfo["url"].toString();
+    blogInfo[ "apiUrl" ] = postInfo["xmlrpc"].toString();
+    blogInfo[ "title" ] = postInfo["blogName"].toString();
     kDebug() << "Blog information retrieved: ID =" << blogInfo["id"]
-        << ", Name =" << blogInfo["name"];
+        << ", Name =" << blogInfo["title"];
     blogsList << blogInfo;
   }
   emit q->listedBlogs( blogsList );
@@ -293,7 +296,7 @@ void Blogger1Private::slotListRecentPosts( const QList<QVariant> &result, const
   int count = id.toInt(); // not sure if needed, actually the API should
 // not give more posts
 
-  kDebug() << "Blog::slotListRecentPosts";
+  kDebug();
   kDebug() << "TOP:" << result[0].typeName();
 
   QList <BlogPost> fetchedPostList;
@@ -334,7 +337,7 @@ void Blogger1Private::slotListRecentPosts( const QList<QVariant> &result, const
 void Blogger1Private::slotFetchPost( const QList<QVariant> &result, const QVariant &id )
 {
   Q_Q( Blogger1 );
-  kDebug() << "Blog::slotFetchPost";
+  kDebug();
 
   KBlog::BlogPost *post = mCallMap[ id.toInt() ];
   mCallMap.remove( id.toInt() );
@@ -345,6 +348,7 @@ void Blogger1Private::slotFetchPost( const QList<QVariant> &result, const QVaria
   kDebug () << "TOP:" << result[0].typeName();
   if ( result[0].type() == QVariant::Map && readPostFromMap( post, result[0].toMap() ) ) {
     kDebug() << "Emitting fetchedPost()";
+    post->setStatus( KBlog::BlogPost::Fetched );
     emit q->fetchedPost( post );
   } else {
     kError() << "Could not fetch post out of the result from the server.";
@@ -361,7 +365,7 @@ void Blogger1Private::slotCreatePost( const QList<QVariant> &result, const QVari
   KBlog::BlogPost *post = mCallMap[ id.toInt() ];
   mCallMap.remove( id.toInt() );
 
-  kDebug() << "Blog::slotCreatePost";
+  kDebug();
   //array of structs containing ISO.8601
   // dateCreated, String userid, String postid, String content;
   // TODO: Time zone for the dateCreated!
@@ -394,12 +398,12 @@ void Blogger1Private::slotModifyPost( const QList<QVariant> &result, const QVari
   KBlog::BlogPost *post = mCallMap[ id.toInt() ];
   mCallMap.remove( id.toInt() );
 
-  kDebug() << "Blog::slotModifyPost";
+  kDebug();
   //array of structs containing ISO.8601
   // dateCreated, String userid, String postid, String content;
   // TODO: Time zone for the dateCreated!
   kDebug() << "TOP:" << result[0].typeName();
-  if ( result[0].type() != QVariant::Bool ) {
+  if ( result[0].type() != QVariant::Bool && result[0].type() != QVariant::Int ) {
     kError() << "Could not read the result, not a boolean.";
     emit q->errorPost( Blogger1::ParsingError,
                           i18n( "Could not read the result, not a boolean." ),
@@ -418,12 +422,12 @@ void Blogger1Private::slotRemovePost( const QList<QVariant> &result, const QVari
   KBlog::BlogPost *post = mCallMap[ id.toInt() ];
   mCallMap.remove( id.toInt() );
 
-  kDebug() << "Blog::slotRemovePost";
+  kDebug() << "slotRemovePost";
   //array of structs containing ISO.8601
   // dateCreated, String userid, String postid, String content;
   // TODO: Time zone for the dateCreated!
   kDebug() << "TOP:" << result[0].typeName();
-  if ( result[0].type() != QVariant::Bool ) {
+  if ( result[0].type() != QVariant::Bool && result[0].type() != QVariant::Int ) {
     kError() << "Could not read the result, not a boolean.";
     emit q->errorPost( Blogger1::ParsingError,
                           i18n( "Could not read the result, not a boolean." ),
@@ -441,9 +445,13 @@ void Blogger1Private::slotError( int number,
 {
   Q_Q( Blogger1 );
   Q_UNUSED( number );
+  kDebug() << "An error occurred: " << errorString;
   BlogPost *post = mCallMap[ id.toInt() ];
 
-  emit q->errorPost( Blogger1::XmlRpc, errorString, post );
+  if(post)
+    emit q->errorPost( Blogger1::XmlRpc, errorString, post );
+  else
+    emit q->error( Blogger1::XmlRpc, errorString );
 }
 
 bool Blogger1Private::readPostFromMap(
@@ -459,32 +467,39 @@ bool Blogger1Private::readPostFromMap(
 
   KDateTime dt( postInfo["dateCreated"].toDateTime(), KDateTime::UTC );
   if ( dt.isValid() && !dt.isNull() ) {
-    post->setCreationDateTime( dt );
+    post->setCreationDateTime( dt.toLocalZone() );
   }
   dt = KDateTime ( postInfo["lastModified"].toDateTime(), KDateTime::UTC );
   if ( dt.isValid() && !dt.isNull() ) {
-    post->setModificationDateTime( dt );
+    post->setModificationDateTime( dt.toLocalZone() );
   }
-  post->setPostId( postInfo["postid"].toString() );
+  post->setPostId( postInfo["postid"].toString().isEmpty() ? postInfo["postId"].toString() :
+                   postInfo["postid"].toString() );
 
   QString title( postInfo["title"].toString() );
   QString description( postInfo["description"].toString() );
-  QString contents( postInfo["content"].toString() );
+  QString contents;
+  if( postInfo["content"].type() == QVariant::ByteArray ) {
+    QByteArray tmpContent = postInfo["content"].toByteArray();
+    contents = QString::fromUtf8(tmpContent.data(), tmpContent.size());
+  } else {
+    contents = postInfo["content"].toString();
+  }
   QStringList category;
 
   // Check for hacked title/category support (e.g. in Wordpress)
   QRegExp titleMatch = QRegExp( "<title>([^<]*)</title>" );
   QRegExp categoryMatch = QRegExp( "<category>([^<]*)</category>" );
-  contents.remove( titleMatch );
-  if ( titleMatch.numCaptures() > 0 ) {
+  if(contents.indexOf(titleMatch) != -1) {
     // Get the title value from the regular expression match
     title = titleMatch.cap( 1 );
   }
-  contents.remove( categoryMatch );
-  if ( categoryMatch.numCaptures() > 0 ) {
-    // Get the category value from the regular expression match
-    category = categoryMatch.capturedTexts();
+  if ( contents.indexOf(categoryMatch) != -1 ) {
+      // Get the category value from the regular expression match
+      category = categoryMatch.capturedTexts();
   }
+  contents.remove( titleMatch );
+  contents.remove( categoryMatch );
 
   post->setTitle( title );
   post->setContent( contents );
